extern GdkPixmap *pix_globe;
extern GdkPixmap *pix_admin;
extern GdkPixmap *pix_op;
extern GdkPixmap *pix_hop;
extern GdkPixmap *pix_voice;
extern GdkPixmap *pix_server;
extern GdkPixmap *pix_xchat_mini;
extern GdkPixmap *pix_xchat;

extern GdkBitmap *mask_globe;
extern GdkBitmap *mask_admin;
extern GdkBitmap *mask_op;
extern GdkBitmap *mask_hop;
extern GdkBitmap *mask_voice;
extern GdkBitmap *mask_server;
extern GdkBitmap *mask_xchat_mini;
extern GdkBitmap *mask_xchat;

extern GdkPixmap *pixmap_load_from_file (char *file);
extern void pixmaps_init (void);

